---

slug: /boolean
---

# Boolean values

Boolean values include the constants `TRUE` and `FALSE`.

The constants `TRUE` and `FALSE` evaluate to 1 and 0, respectively. The constant names can be any letter and are case-insensitive.

```sql
SELECT TRUE, true, FALSE, false;
+------+------+-------+-------+
| TRUE | true | FALSE | false |
+------+------+-------+-------+
|    1 |    1 |     0 |     0 |
+------+------+-------+-------+
1 row in set (0.001 sec)
```